# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"evaluation": "00_Evaluation.ipynb",
         "Card": "00_card.ipynb",
         "PolicyNetwork": "01_model.ipynb",
         "uniform_initializer": "01_model.ipynb",
         "CriticNetwork": "01_model.ipynb"}

modules = ["Evaluation.py",
           "card.py",
           "model.py"]

doc_url = "https://yelloooowww.github.io/curl_navi/"

git_url = "https://github.com/yelloooowww/curl_navi/tree/master/"

def custom_doc_links(name): return None
